@@ -156,7 +156,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class,
     MAKE_SIGNAL(NV_CTRL_TEXTURE_CLAMPING);
     MAKE_SIGNAL(NV_CTRL_FSAA_APPLICATION_CONTROLLED);
     MAKE_SIGNAL(NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED);
-    MAKE_SIGNAL(NV_CTRL_IMAGE_SHARPENING);
     MAKE_SIGNAL(NV_CTRL_TV_OVERSCAN);  
     MAKE_SIGNAL(NV_CTRL_TV_FLICKER_FILTER);
     MAKE_SIGNAL(NV_CTRL_TV_BRIGHTNESS);
@@ -216,7 +215,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class,
     MAKE_SIGNAL(NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB);
     MAKE_SIGNAL(NV_CTRL_PCI_ID);
     MAKE_SIGNAL(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE);
-    MAKE_SIGNAL(NV_CTRL_IMAGE_SHARPENING_DEFAULT);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION);
     MAKE_SIGNAL(NV_CTRL_GPU_COOLER_MANUAL_CONTROL);
     MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_LEVEL);
